@@ -22,10 +22,12 @@
 #include <glib/gi18n.h>
 
 #include "gsm-system.h"
-#ifdef HAVE_OLD_UPOWER
+
+#include "gsm-systemd.h"
+
+#ifdef HAVE_CONSOLEKIT
 #include "gsm-consolekit.h"
 #endif
-#include "gsm-systemd.h"
 
 enum {
         REQUEST_COMPLETED,
@@ -83,6 +85,8 @@ gsm_system_null_init_iface (GsmSystemInterface *iface)
         iface->can_switch_user   = (void *) return_false;
         iface->can_stop          = (void *) return_false;
         iface->can_restart       = (void *) return_false;
+        iface->can_restart_to_firmware_setup = (void *) return_false;
+        iface->set_restart_to_firmware_setup = (void *) do_nothing;
         iface->can_suspend       = (void *) return_false;
         iface->can_hibernate     = (void *) return_false;
         iface->attempt_stop      = (void *) do_nothing;
@@ -95,6 +99,7 @@ gsm_system_null_init_iface (GsmSystemInterface *iface)
         iface->remove_inhibitor  = (void *) do_nothing;
         iface->prepare_shutdown  = (void *) do_nothing;
         iface->complete_shutdown = (void *) do_nothing;
+        iface->is_last_session_for_user = (void *) return_false;
 }
 
 static void
@@ -152,6 +157,19 @@ gsm_system_can_restart (GsmSystem *system)
         return GSM_SYSTEM_GET_IFACE (system)->can_restart (system);
 }
 
+gboolean
+gsm_system_can_restart_to_firmware_setup (GsmSystem *system)
+{
+        return GSM_SYSTEM_GET_IFACE (system)->can_restart_to_firmware_setup (system);
+}
+
+void
+gsm_system_set_restart_to_firmware_setup (GsmSystem *system,
+                                          gboolean   enable)
+{
+        GSM_SYSTEM_GET_IFACE (system)->set_restart_to_firmware_setup (system, enable);
+}
+
 gboolean
 gsm_system_can_suspend (GsmSystem *system)
 {
@@ -216,6 +234,12 @@ gsm_system_is_login_session (GsmSystem *system)
         return GSM_SYSTEM_GET_IFACE (system)->is_login_session (system);
 }
 
+gboolean
+gsm_system_is_last_session_for_user (GsmSystem *system)
+{
+        return GSM_SYSTEM_GET_IFACE (system)->is_last_session_for_user (system);
+}
+
 /**
  * gsm_system_is_active:
  *
@@ -254,7 +278,8 @@ gsm_get_system (void)
                         g_debug ("Using systemd for session tracking");
                 }
         }
-#ifdef HAVE_OLD_UPOWER
+
+#ifdef HAVE_CONSOLEKIT
         if (system == NULL) {
                 system = GSM_SYSTEM (gsm_consolekit_new ());
                 if (system != NULL) {
